# Thank you ztz for providing the name!!!  
## Beautiful girl's knowledge of physics
## Original:
### 一位出水芙蓉 沉鱼落雁  
### 方桃譬李 国色天香  
### 光艳逼人 耀如春华  
### 琼花玉貌 人面桃花  
### 天生丽质 桃羞杏让  
### 莺惭燕妨 倾国倾城  
### 窈窕淑女 般般入画  
### 姿容绝代 花颜月貌  
### 姑射神人 浓桃艳李  
### 娇艳欲滴 妍姿艳质  
### 朱唇粉面 尽态极妍  
### 艳冠群芳的美少女的物理知识  

-------------------------------------------------
## What's new:  
### This release represents the release of the DaMei library as an informal version  